"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getConfig = exports.getConfigFile = exports.defaultConfig = exports.CONFIG_FILE_NAMES = exports.EXTENSION_TARGET = void 0;
const fs_1 = require("fs");
const find_up_1 = __importDefault(require("find-up"));
const yaml_1 = __importDefault(require("yaml"));
const logger_1 = __importDefault(require("./utils/logger"));
var EXTENSION_TARGET;
(function (EXTENSION_TARGET) {
    EXTENSION_TARGET["CHROME"] = "chrome";
    EXTENSION_TARGET["MOZILLA"] = "mozilla";
})(EXTENSION_TARGET = exports.EXTENSION_TARGET || (exports.EXTENSION_TARGET = {}));
exports.CONFIG_FILE_NAMES = ["cwex.yml", ".cwexrc"];
exports.defaultConfig = {
    include: [],
    exclude: [],
    targets: [...Object.values(EXTENSION_TARGET)],
    rootDir: "./",
    outDir: "out",
};
exports.getConfigFile = async () => {
    return await find_up_1.default(exports.CONFIG_FILE_NAMES);
};
exports.getConfig = async (configPath = "") => {
    const pathToConfig = configPath ? configPath : await exports.getConfigFile();
    let config = Object.assign({}, exports.defaultConfig);
    if (pathToConfig) {
        logger_1.default("Config file found:", pathToConfig);
        try {
            config = Object.assign(Object.assign({}, config), yaml_1.default.parse(fs_1.readFileSync(pathToConfig, "utf8")));
        }
        catch (err) {
            logger_1.default("The config file is invalid. Check that you have a valid YAML file.");
            throw err;
        }
    }
    else {
        logger_1.default("Config file not found.");
    }
    return config;
};
//# sourceMappingURL=config.js.map