"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = require("./config");
const find_up_1 = __importDefault(require("find-up"));
const yaml_1 = __importDefault(require("yaml"));
jest.mock('find-up');
jest.mock('yaml');
jest.mock('fs');
describe('config', () => {
    describe('getConfig', () => {
        beforeEach(() => { });
        afterEach(() => {
            find_up_1.default.mockClear();
        });
        it('should return default config if config file not found', async () => {
            const config = await config_1.getConfig();
            expect(config).toStrictEqual(config_1.defaultConfig);
        });
        it('should merge config from config file with default config', async () => {
            const configFromFile = {
                include: ['file1', 'file2'],
                rootDir: './new/root',
                beforeCompile: './new/before-compile.js',
                targets: ['new-target1', 'new-target2'],
                exclude: ['new.exclude.pattern'],
                manifestOptions: {
                    name: 'New test'
                }
            };
            find_up_1.default.mockImplementationOnce(async () => {
                return 'path/to/config/file';
            });
            yaml_1.default.parse.mockImplementation(() => {
                return configFromFile;
            });
            const config = await config_1.getConfig('path/to/config');
            expect(config).toMatchSnapshot();
        });
        it('should throw an error if config file is invalid', async () => {
            find_up_1.default.mockImplementationOnce(async () => {
                return 'path/to/config/file';
            });
            yaml_1.default.parse.mockImplementation(() => {
                throw new Error('fake!');
            });
            await expect(config_1.getConfig('path/to/config')).rejects.toThrow();
        });
    });
});
//# sourceMappingURL=config.spec.js.map