"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.compileExtension = exports.generateExtensionInfo = void 0;
const webExt = require("web-ext");
const buildBrowserAction = (config) => {
    var _a;
    if ((_a = config.manifestOptions) === null || _a === void 0 ? void 0 : _a.browser_action) {
        return {
            default_icon: config.manifestOptions.browser_action.default_icon,
            default_popup: config.manifestOptions.browser_action.default_popup,
            default_title: config.manifestOptions.browser_action.default_title,
        };
    }
    return {};
};
const buildOptionsUi = (config) => {
    var _a;
    if ((_a = config.manifestOptions) === null || _a === void 0 ? void 0 : _a.options_ui) {
        return {
            page: config.manifestOptions.options_ui.page,
            open_in_tab: config.manifestOptions.options_ui.open_in_tab,
        };
    }
    return undefined;
};
const buildExtensionData = (config) => {
    if (!config.manifestOptions) {
        return null;
    }
    return {
        manifest_version: 2,
        name: config.manifestOptions.name,
        short_name: config.manifestOptions.short_name,
        description: config.manifestOptions.description,
        author: config.manifestOptions.author,
        version: config.manifestOptions.version,
        icons: config.manifestOptions.icons,
        browser_action: buildBrowserAction(config),
        permissions: config.manifestOptions.permissions,
        content_security_policy: config.manifestOptions.content_security_policy,
        background: config.manifestOptions.background,
        options_ui: buildOptionsUi(config),
        offline_enabled: config.manifestOptions.offline_enabled,
        browser_specific_settings: config.manifestOptions.browser_specific_settings,
    };
};
exports.generateExtensionInfo = async (config) => {
    const extensionData = buildExtensionData(config);
    return {
        content: extensionData ? JSON.stringify(extensionData, null, 2) : "",
        fileName: "manifest.json",
        fileType: "json",
    };
};
exports.default = exports.generateExtensionInfo;
exports.compileExtension = async (opts) => {
    return await webExt.cmd.build({
        sourceDir: opts.extensionFilesDir,
        overwriteDest: true,
        artifactsDir: opts.extensionBuildOutputDir,
        filename: opts.config.outFile,
    });
};
//# sourceMappingURL=mozilla.js.map