"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const index_1 = require("./index");
const globby_1 = __importDefault(require("globby"));
jest.mock('globby');
const utils = require('./index');
describe('getFiles', () => {
    beforeEach(() => {
        globby_1.default.mockClear();
    });
    it('should call globby with the passed arguments', async () => {
        await index_1.getFiles(['pattern1', 'pattern2'], {});
        expect(globby_1.default).toHaveBeenCalled();
        expect(globby_1.default).toHaveBeenCalledWith(['pattern1', 'pattern2'], {});
    });
});
describe('getResolvedModule', () => {
    let _reqResolve = require.resolve;
    beforeEach(() => {
        _reqResolve = require.resolve;
        require.resolve = jest.fn();
    });
    afterEach(() => {
        require.resolve = _reqResolve;
    });
    it('should call require.resolve with specified path', () => {
        const res = index_1.getResolvedModule('module/path', { resolver: require.resolve });
        expect(require.resolve).toHaveBeenCalled();
        expect(require.resolve).toHaveBeenCalledWith('module/path');
    });
    it('should return the resolved path', () => {
        require.resolve = jest.fn(() => 'resolved/module/path');
        const res = index_1.getResolvedModule('module/path', { resolver: require.resolve });
        expect(require.resolve).toHaveBeenCalled();
        expect(res).toBe('resolved/module/path');
    });
    it('should return empty string if module not found', () => {
        require.resolve = jest.fn(() => {
            throw new Error('fake!');
        });
        const res = index_1.getResolvedModule('module/path', { resolver: require.resolve });
        expect(require.resolve).toHaveBeenCalled();
        expect(res).toBe('');
    });
});
describe('getResolvedTargetModule', () => {
    beforeEach(() => {
        utils.getResolvedModule = jest.fn();
    });
    afterEach(() => {
        utils.getResolvedModule.mockClear();
    });
    it('should call getResolvedModule with modified path', () => {
        index_1.getResolvedTargetModule('module/path');
        expect(utils.getResolvedModule).toHaveBeenCalled();
        expect(utils.getResolvedModule).toHaveBeenCalledWith('../targets/module/path', expect.anything());
    });
});
//# sourceMappingURL=index.spec.js.map